==> unit-1.0.41-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractDateRangeFilterTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractDateRangeFilterTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Label label;
	public _22_1_0946774713 _22_1_0946774713;
	public DateRangeFilterTemplate._22_1_0946774713. From from;
	public DateRangeFilterTemplate._22_1_0946774713. To to;

    public AbstractDateRangeFilterTemplate(B box) {
        super(box);
        id("dateRangeFilterTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (label == null) label = register(new Label(box()).<Label>id("a_929956521").owner(AbstractDateRangeFilterTemplate.this));
		if (_22_1_0946774713 == null) _22_1_0946774713 = register(new _22_1_0946774713(box()).<_22_1_0946774713>id("a461057211").owner(AbstractDateRangeFilterTemplate.this));
		if (_22_1_0946774713 != null) from = _22_1_0946774713.from;
		if (_22_1_0946774713 != null) to = _22_1_0946774713.to;
	}

	public class Label extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

		public Label(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}
	}

	public class _22_1_0946774713 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public DateRangeFilterTemplate._22_1_0946774713. From from;
		public DateRangeFilterTemplate._22_1_0946774713. To to;

		public _22_1_0946774713(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (from == null) from = register(new From(box()).<From>id("a979259520").owner(AbstractDateRangeFilterTemplate.this));
			if (to == null) to = register(new To(box()).<To>id("a_1393392431").owner(AbstractDateRangeFilterTemplate.this));
		}

		public class From extends io.intino.alexandria.ui.displays.components.DateEditable<io.intino.alexandria.ui.displays.notifiers.DateEditableNotifier, B>  {

			public From(B box) {
				super(box);
				label("Desde");
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class To extends io.intino.alexandria.ui.displays.components.DateEditable<io.intino.alexandria.ui.displays.notifiers.DateEditableNotifier, B>  {

			public To(B box) {
				super(box);
				label("Hasta");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> unit-1.0.53-sources.jar: io/intino/goros/unit/box/ui/displays/templates/AbstractDateRangeFilterTemplate.java <==
package io.intino.goros.unit.box.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractDateRangeFilterTemplate<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public Label label;
	public _24_1_0946774713 _24_1_0946774713;
	public DateRangeFilterTemplate._24_1_0946774713. From from;
	public DateRangeFilterTemplate._24_1_0946774713. To to;

    public AbstractDateRangeFilterTemplate(B box) {
        super(box);
        id("dateRangeFilterTemplate");
    }

    @Override
	public void init() {
		super.init();
		if (label == null) label = register(new Label(box()).<Label>id("a_929956521").owner(AbstractDateRangeFilterTemplate.this));
		if (_24_1_0946774713 == null) _24_1_0946774713 = register(new _24_1_0946774713(box()).<_24_1_0946774713>id("a_550060039").owner(AbstractDateRangeFilterTemplate.this));
		if (_24_1_0946774713 != null) from = _24_1_0946774713.from;
		if (_24_1_0946774713 != null) to = _24_1_0946774713.to;
	}

	public class Label extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

		public Label(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
		}
	}

	public class _24_1_0946774713 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public DateRangeFilterTemplate._24_1_0946774713. From from;
		public DateRangeFilterTemplate._24_1_0946774713. To to;

		public _24_1_0946774713(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (from == null) from = register(new From(box()).<From>id("a169912894").owner(AbstractDateRangeFilterTemplate.this));
			if (to == null) to = register(new To(box()).<To>id("a_1336134129").owner(AbstractDateRangeFilterTemplate.this));
		}

		public class From extends io.intino.alexandria.ui.displays.components.DateEditable<io.intino.alexandria.ui.displays.notifiers.DateEditableNotifier, B>  {

			public From(B box) {
				super(box);
				label("Desde");
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class To extends io.intino.alexandria.ui.displays.components.DateEditable<io.intino.alexandria.ui.displays.notifiers.DateEditableNotifier, B>  {

			public To(B box) {
				super(box);
				label("Hasta");
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}
